# Generated by roxygen2: do not edit by hand

export(accGraph)
export(get_year_pubs)
export(megaGen)
export(powoFam)
export(powoGenera)
export(powoMap)
export(powoSpDist)
export(powoSpecies)
export(saveCSV)
export(topGen)
importFrom(PupillometryR,geom_flat_violin)
importFrom(R.utils,countLines)
importFrom(RColorBrewer,brewer.pal)
importFrom(cowplot,save_plot)
importFrom(data.table,fwrite)
importFrom(dplyr,arrange)
importFrom(dplyr,desc)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,select)
importFrom(dplyr,slice)
importFrom(flora,remove.authors)
importFrom(ggplot2,aes)
importFrom(ggplot2,annotate)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,element_rect)
importFrom(ggplot2,element_text)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_sf)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,ggsave)
importFrom(ggplot2,ggtitle)
importFrom(ggplot2,guide_legend)
importFrom(ggplot2,guides)
importFrom(ggplot2,margin)
importFrom(ggplot2,position_jitter)
importFrom(ggplot2,position_nudge)
importFrom(ggplot2,scale_color_manual)
importFrom(ggplot2,scale_colour_manual)
importFrom(ggplot2,scale_colour_viridis_d)
importFrom(ggplot2,scale_fill_gradientn)
importFrom(ggplot2,scale_fill_viridis_c)
importFrom(ggplot2,scale_fill_viridis_d)
importFrom(ggplot2,scale_x_continuous)
importFrom(ggplot2,scale_y_continuous)
importFrom(ggplot2,stat_bin)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_bw)
importFrom(ggplot2,theme_void)
importFrom(ggplot2,unit)
importFrom(ggplot2,xlab)
importFrom(ggplot2,ylab)
importFrom(magrittr,"%>%")
importFrom(plyr,round_any)
importFrom(rnaturalearth,ne_countries)
importFrom(sf,st_read)
importFrom(sp,merge)
importFrom(tibble,add_column)
importFrom(tibble,add_row)
importFrom(utils,data)
importFrom(utils,download.file)
importFrom(utils,read.csv)
importFrom(utils,unzip)
importFrom(viridisLite,viridis)
